SystemOrganization addCategory: #'Seaside-Security'!

!WAKeyGenerator class methodsFor: '*Seaside-Security' stamp: 'pmm 2/8/2014 14:07'!
current: aKeyGenerator
	current := aKeyGenerator! !

WAConfiguredRequestFilter subclass: #WAFrameOptionsAllowFromFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAFrameOptionsAllowFromFilter commentStamp: 'pmm 8/1/2014 08:53' prior: 0!
I disable a web application to be framed into other web pages. This helps preventing clickjacking attacks.
I only implement ALLOW FROM. If you want DENY or SAMEORIGIN you have to use WAFrameOptionsFilter.

https://developer.mozilla.org/en-US/docs/HTTP/X-Frame-Options
http://www.codinghorror.com/blog/2009/06/we-done-been-framed.html!

!WAFrameOptionsAllowFromFilter methodsFor: 'configuration' stamp: 'pmm 8/1/2014 08:55'!
defaultConfiguration
	^ WAUserConfiguration new
		addParent: WAFrameOptionsAllowFromFilterConfiguration instance;
		yourself! !

!WAFrameOptionsAllowFromFilter methodsFor: 'processing' stamp: 'pmm 8/16/2014 16:56'!
handleFiltered: aRequestContext
	| origin |
	origin := self origin.
	origin isEmptyOrNil ifFalse: [
		aRequestContext response frameOptions: 'ALLOW FROM ', origin ].
	super handleFiltered: aRequestContext! !

!WAFrameOptionsAllowFromFilter methodsFor: 'configuration' stamp: 'pmm 8/1/2014 08:55'!
origin
	^ self configuration at: #origin! !

WAConfiguredRequestFilter subclass: #WAFrameOptionsFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAFrameOptionsFilter commentStamp: 'pmm 8/1/2014 08:51' prior: 0!
I disable a web application to be framed into other web pages. This helps preventing clickjacking attacks.
I only implement DENY and SAMEORIGIN. If you want ALLOW FROM you have to use WAFrameOptionsAllowFromFilter.

https://developer.mozilla.org/en-US/docs/HTTP/X-Frame-Options
http://www.codinghorror.com/blog/2009/06/we-done-been-framed.html!

!WAFrameOptionsFilter methodsFor: 'configuration' stamp: 'pmm 2/9/2014 12:48'!
defaultConfiguration
	^ WAUserConfiguration new
		addParent: WAFrameOptionsFilterConfiguration instance;
		yourself! !

!WAFrameOptionsFilter methodsFor: 'configuration' stamp: 'pmm 2/9/2014 12:48'!
frameOptions
	^ self configuration at: #frameOptions! !

!WAFrameOptionsFilter methodsFor: 'processing' stamp: 'pmm 8/16/2014 16:56'!
handleFiltered: aRequestContext
	aRequestContext response frameOptions: self frameOptions.
	super handleFiltered: aRequestContext! !

WAConfiguredRequestFilter subclass: #WAStrictTransportSecurityFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAStrictTransportSecurityFilter commentStamp: 'pmm 2/9/2014 12:38' prior: 0!
I implement strict transport security (STS) for Seaside. STS tries to prevent users from accidentially using non SSL versions of your application. 
 
http://www.imperialviolet.org/2010/01/26/sts.html
http://lists.w3.org/Archives/Public/www-archive/2009Sep/att-0051/draft-hodges-strict-transport-sec-05.plain.html
https://developer.mozilla.org/en-US/docs/Security/HTTP_Strict_Transport_Security!

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'pmm 1/23/2011 21:13'!
defaultConfiguration
	^ WAUserConfiguration new
		addParent: WAStrictTransportSecurityFilterConfiguration instance;
		yourself! !

!WAStrictTransportSecurityFilter methodsFor: 'processing' stamp: 'pmm 1/23/2011 21:27'!
handleFiltered: aRequestContext
	"Adds a Secure-Transport-Security header in case the application is transmitted over HTTPS."
	
	| request |
	request := aRequestContext request.
	request isSsl
		ifTrue: [
			aRequestContext response strictTransportSecurity: self maxAge includeSubDomains: self includeSubDomains.
			super handleFiltered: aRequestContext ]
		ifFalse: [
			| safeUrl |
			safeUrl := request url copy.
			safeUrl host: request host.
			safeUrl scheme: 'https'.
			aRequestContext redirectTo: safeUrl ]! !

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'as 1/22/2011 09:47'!
includeSubDomains
	^ self configuration at: #includeSubDomains! !

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'as 1/22/2011 09:47'!
maxAge
	^ self configuration at: #maxAge! !

WARequestFilter subclass: #WAContentSecurityPolicyFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAContentSecurityPolicyFilter commentStamp: 'pmm 8/1/2014 12:10' prior: 0!
I disable inline JavaScript and CSS and allow content only from the current origin.

http://www.html5rocks.com/en/tutorials/security/content-security-policy/!

!WAContentSecurityPolicyFilter methodsFor: 'processing' stamp: 'pmm 8/16/2014 16:56'!
handleFiltered: aRequestContext
	aRequestContext response headerAt: 'Content-Security-Policy' put: 'default-src ''self'''.
	super handleFiltered: aRequestContext! !

WARequestFilter subclass: #WANoSniffFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WANoSniffFilter commentStamp: 'pmm 2/9/2014 12:39' prior: 0!
I disable content type sniffing in some browsers.

http://blog.fox-it.com/2012/05/08/mime-sniffing-feature-or-vulnerability/
http://security.stackexchange.com/questions/12896/does-x-content-type-options-really-prevent-content-sniffing-attacks!

!WANoSniffFilter methodsFor: 'processing' stamp: 'pmm 2/6/2014 16:10'!
handleFiltered: aRequestContext
	aRequestContext response noSniff.
	super handleFiltered: aRequestContext! !

!GRPackage class methodsFor: '*seaside-security' stamp: 'pmm 2/8/2014 16:16'!
seasideSecurity
	^ self new
		name: 'Seaside-Security';
		addDependency: 'Seaside-Core';
		url: #seasideUrl;
		yourself! !

WASystemConfiguration subclass: #WAFrameOptionsAllowFromFilterConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAFrameOptionsAllowFromFilterConfiguration commentStamp: 'pmm 8/1/2014 08:52' prior: 0!
I am the configuration for WAFrameOptionsAllowFromFilter.!

!WAFrameOptionsAllowFromFilterConfiguration methodsFor: 'description' stamp: 'pmm 8/1/2014 08:55'!
describeOn: config
	(config string: #origin)
		comment: 'The origin from where framing should be allowed (unsupported by IE).'! !

WASystemConfiguration subclass: #WAFrameOptionsFilterConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAFrameOptionsFilterConfiguration commentStamp: 'pmm 2/9/2014 12:45' prior: 0!
I am the configuration for WAFrameOptionsFilter.!

!WAFrameOptionsFilterConfiguration methodsFor: 'description' stamp: 'pmm 8/1/2014 08:50'!
describeOn: config
	(config list: #frameOptions)
		comment: 'The places where framing should be allowed.';
		options: [ #('DENY' 'SAMEORIGIN') ];
		default: 'DENY'! !

WASystemConfiguration subclass: #WAStrictTransportSecurityFilterConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAStrictTransportSecurityFilterConfiguration commentStamp: 'pmm 2/9/2014 12:38' prior: 0!
I am the configuration for WAStrictTransportSecurityFilter.!

!WAStrictTransportSecurityFilterConfiguration methodsFor: 'description' stamp: 'pmm 2/9/2014 12:13'!
describeOn: config
	(config integer: #maxAge)
		comment: 'The number of seconds the user agent should remember receipt of this header field from this server.';
		default: 3600 * 24 * 14. "two weeks"
	(config boolean: #includeSubDomains)
		comment: 'If true signals to the user agent that the STS Policy applies to this STS Server as well as any subdomains of the server''s fully qualified domain name.';
		default: false! !

!WAResponse methodsFor: '*seaside-security' stamp: 'pmm 2/6/2014 16:08'!
noSniff
	"trun off content sniffing
	http://blogs.msdn.com/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
	
	Sending the new X-Content-Type-Options response header with the value nosniff will prevent Internet Explorer from MIME-sniffing a response away from the declared content-type."
	self headerAt: 'X-Content-Type-Options' put: 'nosniff'! !
